@@ -5,7 +5,7 @@ use warnings;
 package Path::Tiny;
 # ABSTRACT: File path utility
 
-our $VERSION = '0.071'; # TRIAL from Path-Tiny-0.071-TRIAL.tar.gz
+our $VERSION = '0.073'; # TRIAL
 
 # Dependencies
 use Config;
@@ -1499,15 +1499,17 @@ sub spew {
     my $binmode = $args->{binmode};
     # get default binmode from caller's lexical scope (see "perldoc open")
     $binmode = ( ( caller(0) )[10] || {} )->{'open>'} unless defined $binmode;
-    my $temp = path( $self->[PATH] . $$ . int( rand( 2**31 ) ) );
+
+    # spewing need to follow the link
+    # and create the tempfile in the same dir
+    my $resolved_path = $self->[PATH];
+    $resolved_path = readlink $resolved_path while -l $resolved_path;
+
+    my $temp = path( $resolved_path . $$ . int( rand( 2**31 ) ) );
     my $fh = $temp->filehandle( { exclusive => 1, locked => 1 }, ">", $binmode );
     print {$fh} map { ref eq 'ARRAY' ? @$_ : $_ } @data;
     close $fh or $self->_throw( 'close', $temp->[PATH] );
 
-    # spewing need to follow the link
-    # and replace the destination instead
-    my $resolved_path = $self->[PATH];
-    $resolved_path = readlink $resolved_path while -l $resolved_path;
     return $temp->move($resolved_path);
 }
 
@@ -1785,7 +1787,7 @@ Path::Tiny - File path utility
 
 =head1 VERSION
 
-version 0.071
+version 0.073
 
 =head1 SYNOPSIS
 
@@ -1851,6 +1853,9 @@ On Windows, that means they will not have CRLF translation from the C<:crlf> IO
 layer.  Installing L<Unicode::UTF8> 0.58 or later will speed up C<*_utf8>
 situations in many cases and is highly recommended.
 
+This module depends heavily on PerlIO layers for correct operation and thus
+requires Perl 5.008001 or later.
+
 =head1 CONSTRUCTORS
 
 =head2 path
@@ -2788,7 +2793,7 @@ David Golden <dagolden@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Alex Efros Chris Williams David Steinbrunner Doug Bell Gabor Szabo Gabriel Andrade George Hartzell Geraud Continsouzas Goro Fuji Graham Knop James Hunt Karen Etheridge Martin Kjeldsen Michael G. Schwern Philippe Bruhat (BooK) Regina Verbae regina-verbae Smylers Tatsuhiko Miyagawa Toby Inkster Yanick Champoux 김도형 - Keedi Kim
+=for stopwords Alex Efros Chris Williams David Golden Steinbrunner Doug Bell Gabor Szabo Gabriel Andrade George Hartzell Geraud Continsouzas Goro Fuji Graham Knop James Hunt Karen Etheridge Mark Ellis Martin Kjeldsen Michael G. Schwern Philippe Bruhat (BooK) Regina Verbae Smylers Tatsuhiko Miyagawa Toby Inkster Yanick Champoux 김도형 - Keedi Kim
 
 =over 4
 
@@ -2802,6 +2807,10 @@ Chris Williams <bingos@cpan.org>
 
 =item *
 
+David Golden <xdg@xdg.me>
+
+=item *
+
 David Steinbrunner <dsteinbrunner@pobox.com>
 
 =item *
@@ -2842,6 +2851,10 @@ Karen Etheridge <ether@cpan.org>
 
 =item *
 
+Mark Ellis <mark.ellis@cartridgesave.co.uk>
+
+=item *
+
 Martin Kjeldsen <mk@bluepipe.dk>
 
 =item *
@@ -2858,10 +2871,6 @@ Regina Verbae <regina-verbae@users.noreply.github.com>
 
 =item *
 
-regina-verbae <regina-verbae@users.noreply.github.com>
-
-=item *
-
 Smylers <Smylers@stripey.com>
 
 =item *
